Fedora Badges
=============

This repo contains the consumer and the command nessicary to hook the fedora
badges stack (Tahrir, Tahrir-API, Tahrir-REST) into fedmsg. Included is an
Example consumer which can be used as a template to create more complex
consumers.
